==> vue3-components-0.2.6.tgz: package/es/table/src/props.js <==
import e from "axios";
const a = {
  options: Array,
  editRow: Boolean,
  showPagination: {
    type: Boolean
  },
  server: {
    type: Function,
    default: e
  },
  getUrl: String,
  withDataPath: {
    type: [String, Boolean],
    default: null
  },
  withPagePath: {
    type: [String, Boolean],
    default: null
  },
  withQuery: Object,
  withQueryPath: {
    type: [String, Boolean],
    default: null
  },
  stringify: Boolean,
  getConfig: {
    type: Object,
    default: () => ({
      method: "get"
    })
  },
  replaceFields: {
    type: Object,
    default: () => ({ pageSize: "pageSize", currentPage: "currentPage" })
  },
  dataPath: {
    type: String,
    default: "data.data"
  },
  totalPath: {
    type: String,
    default: "data.total"
  },
  showLoadInGet: {
    type: Boolean,
    default: !0
  },
  elementLoadingText: {
    type: String,
    default: "\u6B63\u5728\u52A0\u8F7D\u4E2D..."
  },
  elLoadingTextTimeout: {
    type: Number,
    default: 8e3
  },
  elLoadingTextTimeoutText: {
    type: String,
    default: "\u6570\u636E\u52A0\u8F7D\u8F83\u6162\uFF0C\u8BF7\u8010\u5FC3\u7B49\u5F85..."
  },
  emptyTip: {
    type: String,
    default: "\u6B63\u5728\u52A0\u8F7D\u4E2D..."
  },
  emptyTipTimeout: {
    type: Number,
    default: 8e3
  },
  emptyTipTimeoutText: {
    type: String,
    default: "\u6570\u636E\u52A0\u8F7D\u8F83\u6162\uFF0C\u8BF7\u8010\u5FC3\u7B49\u5F85..."
  },
  defaultCurrentPage: Number,
  defaultPageSize: Number
}, l = {
  edit: null,
  delete: null,
  confirmEditRow: null,
  cancelEditRow: null,
  confirmEditCell: null,
  cancelEditCell: null,
  beforeGetData: (t) => typeof t == "object",
  afterGetData: (t) => typeof t == "object",
  failToGetData: (t) => typeof t == "object"
};
export {
  l as tableEmits,
  a as tableProps
};

==> vue3-components-0.2.17.tgz: package/es/table/src/props.js <==
import e from "axios";
const a = {
  options: Array,
  editRow: Boolean,
  showPagination: {
    type: Boolean
  },
  server: {
    type: Function,
    default: e
  },
  getUrl: String,
  withDataPath: {
    type: [String, Boolean],
    default: null
  },
  withPagePath: {
    type: [String, Boolean],
    default: null
  },
  withQuery: Object,
  withQueryPath: {
    type: [String, Boolean],
    default: null
  },
  stringify: Boolean,
  getConfig: {
    type: Object,
    default: () => ({
      method: "get"
    })
  },
  replaceFields: {
    type: Object,
    default: () => ({ pageSize: "pageSize", currentPage: "currentPage" })
  },
  dataPath: {
    type: String,
    default: "data.data"
  },
  totalPath: {
    type: String,
    default: "data.total"
  },
  showLoadInGet: {
    type: Boolean,
    default: !0
  },
  elementLoadingText: {
    type: String,
    default: "\u6B63\u5728\u52A0\u8F7D\u4E2D..."
  },
  elLoadingTextTimeout: {
    type: Number,
    default: 8e3
  },
  elLoadingTextTimeoutText: {
    type: String,
    default: "\u6570\u636E\u52A0\u8F7D\u8F83\u6162\uFF0C\u8BF7\u8010\u5FC3\u7B49\u5F85..."
  },
  emptyTip: {
    type: String,
    default: "\u6B63\u5728\u52A0\u8F7D\u4E2D..."
  },
  emptyTipTimeout: {
    type: Number,
    default: 8e3
  },
  emptyTipTimeoutText: {
    type: String,
    default: "\u6570\u636E\u52A0\u8F7D\u8F83\u6162\uFF0C\u8BF7\u8010\u5FC3\u7B49\u5F85..."
  },
  defaultCurrentPage: Number,
  defaultPageSize: Number,
  actionConfig: {
    type: Object,
    default: () => ({})
  }
}, l = {
  edit: null,
  delete: null,
  confirmEditRow: null,
  cancelEditRow: null,
  confirmEditCell: null,
  cancelEditCell: null,
  beforeGetData: (t) => typeof t == "object",
  afterGetData: (t) => typeof t == "object",
  failToGetData: (t) => typeof t == "object"
};
export {
  l as tableEmits,
  a as tableProps
};
